@@ -49,7 +49,7 @@ class TAPD(object):
         if not isinstance(workspace_id, int):
             raise TypeError("workspace_id must be int.")
 
-        parms = {"workspace_id": workspace_id, limit=200}
+        parms = {"workspace_id": workspace_id}
 
         
         if status:
